cytoflowgui.op_plugins package
==============================

Submodules
----------

cytoflowgui.op_plugins.hlog module
----------------------------------

.. automodule:: cytoflowgui.op_plugins.hlog
    :members:
    :undoc-members:
    :show-inheritance:

cytoflowgui.op_plugins.logicle module
-------------------------------------

.. automodule:: cytoflowgui.op_plugins.logicle
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflowgui.op_plugins
    :members:
    :undoc-members:
    :show-inheritance:
